@@ -480,6 +480,9 @@ class OpenEVSE:
             # RAPI commands
             _LOGGER.debug("Setting current via RAPI")
             command = f"$SC {amps} N"
+            # Different parameters for older firmware
+            if self._version_check("2.9.1"):
+                command = f"$SC {amps} V"
             response, msg = await self.send_command(command)
             _LOGGER.debug("Set current response: %s", msg)
 
@@ -649,6 +652,10 @@ class OpenEVSE:
             _LOGGER.debug("Non-semver firmware version detected.")
         return False
 
+    def version_check(self, min_version: str, max_version: str = "") -> bool:
+        """Unprotected function call for version checking."""
+        return self._version_check(min_version=min_version, max_version=max_version)
+
     # HTTP Posting of grid voltage
     async def grid_voltage(self, voltage: int | None = None) -> None:
         """Send pushed sensor data to grid voltage."""
